package tools.descartes.dql.connector.kieker.filter;

import kieker.analysis.AnalysisController;
import kieker.analysis.IAnalysisController;
import kieker.analysis.exception.AnalysisConfigurationException;
import kieker.analysis.plugin.reader.filesystem.FSReader;
import kieker.common.configuration.Configuration;;


public class KiekerReader {
	private final String[] inputDirs;

	public KiekerReader(String[] inputDirs) {
		if (inputDirs.length == 0) {
			System.out.println("No directory given as argument");
			System.exit(1);
		}
		this.inputDirs = inputDirs;
	}

	public String[] getInputDirs() {
		return inputDirs;
	}

	public void read() {

		// Create Kieker.Analysis instance
		final IAnalysisController analysisInstance = new AnalysisController();

		// Set filesystem monitoring log input directory for our analysis
		final Configuration readerConfiguration = new Configuration();
		readerConfiguration.setProperty(FSReader.CONFIG_PROPERTY_NAME_INPUTDIRS, Configuration.toProperty(inputDirs));
		final FSReader fsReader = new FSReader(readerConfiguration, analysisInstance);

		// Create and register our own consumer

		// final Configuration exTimeFilterConfig = new Configuration();


		final ResourceFilter resourceFilter = new ResourceFilter(new Configuration(), analysisInstance);
		final UtilizationFilter utilizationFilter = new UtilizationFilter(new Configuration(), analysisInstance);
		final ExecutionTimeFilter executionTimeFilter = new ExecutionTimeFilter(new Configuration(), analysisInstance);
		final ClassAndInterfaceFilter responseTimeFilter = new ClassAndInterfaceFilter(new Configuration(), analysisInstance);



		try {
			// Connect components.

			analysisInstance.connect(fsReader, FSReader.OUTPUT_PORT_NAME_RECORDS, resourceFilter,
					resourceFilter.INPUT_PORT_NAME);

			analysisInstance.connect(fsReader, FSReader.OUTPUT_PORT_NAME_RECORDS, utilizationFilter,
					utilizationFilter.INPUT_PORT_NAME);

			analysisInstance.connect(fsReader, FSReader.OUTPUT_PORT_NAME_RECORDS, executionTimeFilter,
					executionTimeFilter.INPUT_PORT_NAME);
			
			analysisInstance.connect(fsReader, FSReader.OUTPUT_PORT_NAME_RECORDS, responseTimeFilter,
					responseTimeFilter.INPUT_PORT_NAME);

			// Start the analysis
			analysisInstance.run();
		} catch (final AnalysisConfigurationException e) {
			e.printStackTrace();
		}

	}
}
